@@ -2,7 +2,7 @@
 # the R software environment .
 # Copyright (C) 2012
 # University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu, 
+# Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,20 +19,33 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # or see http://www.r-project.org/Licenses/GPL-2
 
-LKrig.cov.plot<- function( LKinfo, NP=200){
- grid.info<- LKinfo$grid.info
- ux<- seq( grid.info$xmin, grid.info$xmax,,NP)
- uy<- seq( grid.info$ymin, grid.info$ymax,,NP)
- x1<- cbind( ux,  rep(uy[NP/2], NP) )
- x2<- cbind( ux[NP/2], uy[NP/2] )
-  d<- c( rdist(x1,x2) )
-# evaluate the covariance from the LKinfo object devised from table
-# to approximate the Matern in the X direction
- y<-    c( LKrig.cov( x1,x2, LKinfo) ) 
- x1<- cbind( rep(ux[NP/2], NP), uy)
- d2<- c( rdist(x1,x2) )
- 
-# same in Y direction    
- y2<- c( LKrig.cov( x1,x2, LKinfo) )
- return( list(d= cbind(d,d2), cov=cbind( y,y2) ) )
+LKrig.cov.plot <- function(LKinfo, NP = 200, center = NULL, 
+    xlim = NULL, ylim = NULL) {
+    grid.info <- LKinfo$grid.info
+    if (is.null(xlim)) {
+        xlim <- c(grid.info$xmin, grid.info$xmax)
+    }
+    ux <- seq(xlim[1], xlim[2], , NP)
+    
+    if (is.null(ylim)) {
+        ylim <- c(grid.info$ymin, grid.info$ymax)
+    }
+    uy <- seq(ylim[1], ylim[2], , NP)
+    
+    if (is.null(center)) {
+        center <- rbind(c(ux[NP/2], uy[NP/2]))
+    }
+    x1 <- cbind(ux, rep(center[2], NP))
+    x2 <- rbind(center)
+    d <- c(rdist(x1, x2))
+    # evaluate the covariance from the LKinfo object devised from table
+    # to approximate the Matern in the X direction
+    y <- c(LKrig.cov(x1, x2, LKinfo))
+    x1 <- cbind(rep(center[1], NP), uy)
+    d2 <- c(rdist(x1, x2))
+    
+    # same in Y direction
+    y2 <- c(LKrig.cov(x1, x2, LKinfo))
+    return(list(d = cbind(d, d2), u = cbind(ux, uy), cov = cbind(y, 
+        y2), center = center, LKinfo = LKinfo))
 }
