@@ -2,7 +2,7 @@
 # the R software environment .
 # Copyright (C) 2012
 # University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu, 
+# Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,10 +19,9 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # or see http://www.r-project.org/Licenses/GPL-2
 
-print.LKrig <-
-function(x, digits=4, ...){
-   LKinfo<- x$LKinfo
-   if (is.matrix(x$residuals)) {
+print.LKrig <- function(x, digits = 4, ...) {
+    LKinfo <- x$LKinfo
+    if (is.matrix(x$residuals)) {
         n <- nrow(x$residuals)
         NData <- ncol(x$residuals)
     }
@@ -40,9 +39,10 @@ function(x, digits=4, ...){
     c2 <- c(c2, x$spatialdriftorder - 1)
     c1 <- c(c1, "Number of parameters in the null space")
     c2 <- c(c2, x$nt)
-    if( x$nZ>0){
-     c1 <- c(c1, "Number of covariates")
-     c2 <- c(c2, x$nZ)}
+    if (x$nZ > 0) {
+        c1 <- c(c1, "Number of covariates")
+        c2 <- c(c2, x$nZ)
+    }
     if (!is.na(x$eff.df)) {
         c1 <- c(c1, " Effective degrees of freedom (EDF)")
         c2 <- c(c2, signif(x$eff.df, digits))
@@ -66,27 +66,45 @@ function(x, digits=4, ...){
     print(sum, quote = FALSE)
     cat(" ", fill = TRUE)
     cat("Covariance Model: Radial Basis/Lattice", fill = TRUE)
-    cat(" Radial Basis R function: ", LKinfo$RadialBasisFunction, fill=TRUE)
-    cat(LKinfo$nlevel, "level(s)", LKinfo$m, " basis functions", fill=TRUE)
-    for( k in 1: LKinfo$nlevel){ 
-      cat("Lattice level", k,"is ", LKinfo$mx[k],"X",LKinfo$my[k], "spacing", LKinfo$delta[k], fill=TRUE)}
-    cat( "Total number of basis functions: ", x$m,  "  with overlap of ", LKinfo$overlap, fill=TRUE)
-    if( length(  LKinfo$alpha[[1]]) ==1){
-    cat("Value(s) for weighting (alpha): ", unlist(LKinfo$alpha),fill = TRUE)}
-    else{
-    cat("alpha values passed as a vector for each level", fill=TRUE)}
-    if( length(  LKinfo$a.wght[[1]]) ==1){
-      a.wght<- unlist( LKinfo$a.wght)
-      cat("Value(s) for lattice dependence (a): ", a.wght,fill = TRUE)
-      cat("Equivalent range based on MRF (delta/sqrt(a-4)):",   LKinfo$delta/sqrt(a.wght-4),
-         fill=TRUE)
+    cat(" Radial Basis R function: ", LKinfo$RadialBasisFunction, 
+        fill = TRUE)
+    cat(LKinfo$nlevel, "level(s)", LKinfo$m, " basis functions", 
+        fill = TRUE)
+    for (k in 1:LKinfo$nlevel) {
+        cat("Lattice level", k, "is ", LKinfo$mx[k], "X", LKinfo$my[k], 
+            "spacing", LKinfo$delta[k], fill = TRUE)
+    }
+    cat("Total number of basis functions: ", x$m, "  with overlap of ", 
+        LKinfo$overlap, fill = TRUE)
+    cat("Type of distance metric used: ", LKinfo$distance.type, 
+        fill = TRUE)
+    if (length(LKinfo$alpha[[1]]) == 1) {
+        cat("Value(s) for weighting (alpha): ", unlist(LKinfo$alpha), 
+            fill = TRUE)
+    }
+    else {
+        cat("alpha values passed as a vector for each level", 
+            fill = TRUE)
+    }
+    if (length(LKinfo$a.wght[[1]]) == 1) {
+        a.wght <- unlist(LKinfo$a.wght)
+        cat("Value(s) for lattice dependence (a): ", a.wght, 
+            fill = TRUE)
+        cat("Equivalent range based on MRF (delta/sqrt(a-4)):", 
+            LKinfo$delta/sqrt(a.wght - 4), fill = TRUE)
+    }
+    else {
+        cat("Value(s) for weighting in GMRF (a.wght): ", unlist(LKinfo$alpha), 
+            fill = TRUE)
+    }
+    if (LKinfo$normalize) {
+        cat("Basis functions normalized so marginal process variance is stationary", 
+            fill = TRUE)
+    }
+    if (LKinfo$edge) {
+        cat("Precision matrix at each level is adjusted at edges", 
+            fill = TRUE)
     }
-    else{
-      cat("Value(s) for weighting in GMRF (a.wght): ", unlist(LKinfo$alpha),fill = TRUE)} 
-    if( LKinfo$normalize){
-      cat("Basis functions normalized so marginal process variance is stationary", fill=TRUE)}
-    if(LKinfo$edge){
-      cat("Precision matrix at each level is adjusted at edges", fill=TRUE)}
     invisible(x)
 }
 
